@@ -49,9 +49,9 @@ class DAppClient:
 
         return results
 
-    async def broadcast(self, queries: List[BroadcastQuery]) -> List[Any]:
+    async def broadcast(self, queries: List[BroadcastQuery], timeout=31) -> List[Any]:
         results = []
-        timeout = aiohttp.ClientTimeout(total=20)
+        timeout = aiohttp.ClientTimeout(total=timeout)
 
         async with aiohttp.ClientSession(timeout=timeout) as session:
             for query in queries:
