@@ -1,8 +1,9 @@
 from json import JSONDecodeError
-
+import sys
 from pydantic import ValidationError
-from .._utils import init_shared_object, setup_app
+
 from wton.config import ConfigNotFoundError
+from .._utils import init_shared_object, setup_app
 from ._utils import echo_error
 from ._sets import EntrypointSet
 
@@ -15,6 +16,9 @@ def main():
     except (FileNotFoundError, JSONDecodeError, ConfigNotFoundError, ValidationError) as e:
         echo_error(e)
 
+    if len(sys.argv) == 2 and sys.argv[1] == "--debug":
+        context.debug_mode = True
+
     try:
         EntrypointSet(context).show()
     except KeyboardInterrupt:
