@@ -1,5 +1,7 @@
 from ._render import ModifiedConsoleRender
+from ._theme import ModifiedTheme
 
 __all__ = [
     'ModifiedConsoleRender',
+    'ModifiedTheme',
 ]
