@@ -3,13 +3,9 @@ from collections import OrderedDict
 from ._base import BaseSet
 from ._keystores import KeystoresSet
 from ._whitelist import WhitelistSet
-from ..._utils import SharedObject
 
 
 class EntrypointSet(BaseSet):
-    def __init__(self, ctx: SharedObject) -> None:
-        super().__init__(ctx)
-
     def _handlers(self) -> OrderedDict:
         ord_dict = OrderedDict()
         ord_dict["Keystores"] = self._handle_keystores
