@@ -43,28 +43,28 @@ class KeystoreSet(BaseSet):
         ]
         verbose = self._prompt(questions)["verbose"]
 
-        self._start_loading()
-        field_names = ['Name', 'Version', 'WC', 'Address', 'Comment']
-        if verbose:
-            field_names += ['State', 'Balance']
+        with self._processing():
+            field_names = ['Name', 'Version', 'WC', 'Address', 'Comment']
+            if verbose:
+                field_names += ['State', 'Balance']
 
-        wallets = self.ctx.keystore.records
+            wallets = self.ctx.keystore.records
 
-        table = md_table()
-        table.field_names = field_names
-        if verbose:
-            wallet_infos = self.ctx.ton_client.get_addresses_information(
-                [wallet.address for wallet in wallets])
+            table = md_table()
+            table.field_names = field_names
+            if verbose:
+                wallet_infos = self.ctx.ton_client.get_addresses_information(
+                    [wallet.address for wallet in wallets])
+
+                for wallet, wallet_info in zip(wallets, wallet_infos):
+                    table.add_row([wallet.name, wallet.version, wallet.workchain,
+                                wallet.address_to_show, wallet.comment,
+                                wallet_info.state, wallet_info.balance])
+            else:
+                for wallet in wallets:
+                    table.add_row([wallet.name, wallet.version, wallet.workchain,
+                                wallet.address_to_show, wallet.comment])
 
-            for wallet, wallet_info in zip(wallets, wallet_infos):
-                table.add_row([wallet.name, wallet.version, wallet.workchain,
-                               wallet.address_to_show, wallet.comment,
-                               wallet_info.state, wallet_info.balance])
-        else:
-            for wallet in wallets:
-                table.add_row([wallet.name, wallet.version, wallet.workchain,
-                               wallet.address_to_show, wallet.comment])
-        self._stop_loading()
         echo_success(table, only_msg=True)
 
     def _handle_transfer(self):
@@ -99,7 +99,6 @@ class KeystoreSet(BaseSet):
                 "wait_for_result", message="Wait until transaction will be completed?", default=True),
         ]
         ans = self._prompt(questions)
-
         amount = float(ans["amount"])
         message = ans["message"]
         destroy_if_zero = ans["destroy_if_zero"]
@@ -111,16 +110,14 @@ class KeystoreSet(BaseSet):
         if transfer_all:
             send_mode |= SendModeEnum.carry_all_remaining_balance
 
-        _mnemonics, _pub_k, _priv_k, wallet = Wallets.from_mnemonics(mnemonics, record.version,
-                                                                     record.workchain)
+        with self._processing():
+            _mnemonics, _pub_k, _priv_k, wallet = Wallets.from_mnemonics(mnemonics, record.version,
+                                                                         record.workchain)
+            # TonDappError('timeout, Code: 0')
+            result = self.ctx.ton_client.transfer(
+                wallet, contact.address, amount, message, send_mode, wait_for_result)
 
-        result = self.ctx.ton_client.transfer(
-            wallet, contact.address, amount, message, send_mode, wait_for_result)
-
-        if wait_for_result:
-            self._parse_broadcast_result(result)
-        else:
-            echo_success()
+        echo_success(result)
 
     def _handle_create_wallet(self):
         questions = [
@@ -207,27 +204,27 @@ class KeystoreSet(BaseSet):
                 wallets_to_create.append(
                     (new_name, comment, contact_name))
 
-        self._start_loading()
-        for wallet_name, comment, contact_name in wallets_to_create:
-            if contact_name:
-                contact = self.ctx.whitelist.get_contact(contact_name)
-                if contact is not None:
-                    raise Exception(
-                        f"Contact with the name '{contact_name}' already exists")
+        with self._processing():
+            for wallet_name, comment, contact_name in wallets_to_create:
+                if contact_name:
+                    contact = self.ctx.whitelist.get_contact(contact_name)
+                    if contact is not None:
+                        raise Exception(
+                            f"Contact with the name '{contact_name}' already exists")
 
-            mnemonics, pub_k, _priv_k, wallet = Wallets.create(
-                version, workchain)
-            self.ctx.keystore.add_record(wallet_name, wallet.address,
-                                         pub_k.hex(), mnemonics, version,
-                                         workchain, comment, save=False)
+                mnemonics, pub_k, _priv_k, wallet = Wallets.create(
+                    version, workchain)
+                self.ctx.keystore.add_record(wallet_name, wallet.address,
+                                            pub_k.hex(), mnemonics, version,
+                                            workchain, comment, save=False)
 
-            if contact_name:
-                self.ctx.whitelist.add_contact(
-                    contact_name, wallet.address.to_string(True), save=False)
+                if contact_name:
+                    self.ctx.whitelist.add_contact(
+                        contact_name, wallet.address.to_string(True), save=False)
+
+            self.ctx.keystore.save()
+            self.ctx.whitelist.save()
 
-        self.ctx.keystore.save()
-        self.ctx.whitelist.save()
-        self._stop_loading()
         echo_success()
 
     def _handle_init_wallet(self):
@@ -250,7 +247,7 @@ class KeystoreSet(BaseSet):
         _mnemonics, _pub_k, _priv_k, wallet = Wallets.from_mnemonics(mnemonics, record.version,
                                                                      record.workchain)
         result = self.ctx.ton_client.deploy_wallet(wallet, wait_for_result)
-        
+
         if wait_for_result:
             self._parse_broadcast_result(result)
         else:
