@@ -52,6 +52,7 @@ class KeystoresSet(BaseSet):
 
     def _handle_restore_keystore(self):
         questions = [
+            inquirer.List("restore_from", message='Restore from', choices=["wton backup", "ton-cli backup"]),
             inquirer.Text(
                 "backup_file_path", message='Enter the path to backup file'),
             inquirer.Text(
@@ -63,13 +64,18 @@ class KeystoresSet(BaseSet):
         ]
         ans = self._prompt(questions)
         name = ans["name"]
+        restore_from = ans["restore_from"]
         backup_file_path = ans["backup_file_path"]
         pass1 = ans["password1"]
         pass2 = ans["password2"]
 
         if self.__validate_passwords(pass1, pass2):
-            self.ctx.keystores.restore_keystore(
-                name, backup_file_path, pass1)
+            if restore_from == "ton-cli backup":
+                self.ctx.keystores.keystores.restore_ton_cli_keystore(
+                    name, backup_file_path, pass1)
+            else:
+                self.ctx.keystores.keystores.restore_wton_keystore(
+                    name, backup_file_path, pass1)
             echo_success()
 
     def __validate_passwords(self, pass1, pass2):
