@@ -68,15 +68,9 @@ class WhitelistSet(BaseSet):
         echo_success()
 
     def _handle_get(self):
-        questions = [
-            inquirer.List(
-                "name",
-                message='Contact to get',
-                choices=[contact.name for contact in self.ctx.whitelist.contacts],
-                carousel=True
-            )
-        ]
-        name = self._prompt(questions)["name"]
+        name = self.__select_contact_or_false('Contact to edit')
+        if name == False:
+            return
 
         contact = self.ctx.whitelist.get_contact(name, raise_none=True)
 
